elegant_nav_bar library

Classes

AppColors
A class containing the color constants used throughout the app
ElegantBottomNavigationBar
A customizable bottom navigation bar with animation effects
ElegantBottomNavigationBarState
A model class representing an item in the navigation bar

Enums

IndicatorPosition
Defines the position of the indicator
IndicatorShape
Defines the shape of the indicator