elegant_nav_bar library
Classes
- AppColors
- A class containing the color constants used throughout the app
- A customizable bottom navigation bar with animation effects
- A model class representing an item in the navigation bar
Enums
- IndicatorPosition
- Defines the position of the indicator
- IndicatorShape
- Defines the shape of the indicator